==> apache-cassandra-2.0.13-src.tar.gz: apache-cassandra-2.0.13-src/src/java/org/apache/cassandra/gms/EchoMessage.java <==
package org.apache.cassandra.gms;
/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */


import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

import org.apache.cassandra.io.IVersionedSerializer;

public class EchoMessage
{
    public static IVersionedSerializer<EchoMessage> serializer = new EchoMessageSerializer();

    public static class EchoMessageSerializer implements IVersionedSerializer<EchoMessage>
    {
        public void serialize(EchoMessage t, DataOutput out, int version) throws IOException
        {
        }

        public EchoMessage deserialize(DataInput in, int version) throws IOException
        {
            return new EchoMessage();
        }

        public long serializedSize(EchoMessage t, int version)
        {
            return 0;
        }
    }
}

==> apache-cassandra-3.0.32-src.tar.gz: apache-cassandra-3.0.32-src/src/java/org/apache/cassandra/gms/EchoMessage.java <==
package org.apache.cassandra.gms;
/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */


import java.io.IOException;

import org.apache.cassandra.io.IVersionedSerializer;
import org.apache.cassandra.io.util.DataInputPlus;
import org.apache.cassandra.io.util.DataOutputPlus;

public final class EchoMessage
{
	public static final EchoMessage instance = new EchoMessage();
	
    public static final IVersionedSerializer<EchoMessage> serializer = new EchoMessageSerializer();

	private EchoMessage()
	{
	}
	
    public static class EchoMessageSerializer implements IVersionedSerializer<EchoMessage>
    {
        public void serialize(EchoMessage t, DataOutputPlus out, int version) throws IOException
        {
        }

        public EchoMessage deserialize(DataInputPlus in, int version) throws IOException
        {
            return EchoMessage.instance;
        }

        public long serializedSize(EchoMessage t, int version)
        {
            return 0;
        }
    }
}
